# YouTube Downloader V1.1

## Requirements

    python>=3.4
    pytube3==9.5.13

## Installation

Open a terminal and execute `git clone https://github.com/Jodagito/YoutubeDownloader` on the destination folder.

Once git finishes clonning the repo navigate to YouTubeDownloader folder.

Inside the YouTubeDownloader folder execute `pip install . --user` to install the package and requirements globally on your system.

## Usage

Execute `YouTubeDownloader`

Follow the CLI instructions.

## To Do

- Allow to download all videos from a specific channel.
- Allow users to pass an URL on file call.
- Clean code.
- Create a progress bar.
- Develop tests.

### Notes

This tool has been developed merely as a learning challenge, isn't intended to have release dates.

If you liked it please share it!
